# cheapodb
[![CircleCI](https://circleci.com/gh/mineralzen/cheapodb.svg?style=svg)](https://circleci.com/gh/mineralzen/cheapodb)
[![PyPI version](https://badge.fury.io/py/cheapodb.svg)](https://badge.fury.io/py/cheapodb) 

A very opinionated, very basic implementation of AWS Glue targeting Athena and S3.  

This is probably only useful to us. We wanted a dirt cheap way to persist scraped, raw data with
querying ability.